polylabelr-package: polylabelr: Find the Pole of Inaccessibility (Visual Center)...

polylabelr-packageR Documentation

polylabelr: Find the Pole of Inaccessibility (Visual Center) of a Polygon

Description

A wrapper around the C++ library 'polylabel' from 'Mapbox', providing an efficient routine for finding the approximate pole of inaccessibility of a polygon, which usually serves as an excellent candidate for labeling of a polygon.

Author(s)

Maintainer: Johan Larsson johanlarsson@outlook.com (ORCID)

Other contributors:

  • Kent Johnson kent@kentsjohnson.com [contributor]

  • Mapbox (polylabel, variant, and geometry libraries) [copyright holder]

See Also

Useful links:


polylabelr documentation built on Jan. 19, 2026, 9:07 a.m.